Welcome to iqcampy
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Our lab, the Rijkserfgoedlaboratorium in Amsterdam, recently acquired a
light weight, mobile and user friendly Specim IQcam spectral camera for
the investigation of artworks. This open source Python package `iqcampy`
is developed in out the open to learn together how to read, visualize
and interpret the spectral image data for this camera.

Let’s dive in!!
